searchData={"items":[{"type":"module","title":"SEO","doc":"```\n/ˈin(t)ərˌnet jo͞os/\nnoun: internet juice\n```\n\nSEO (Search Engine Optimization) provides a framework for Phoenix applications\nto more-easily optimize your site for search engines and displaying rich results\nwhen your URLs are shared across the internet. The better visibility your pages\nhave in search results, the more likely you are to have visitors.","ref":"SEO.html"},{"type":"module","title":"Installation - SEO","doc":"```elixir\ndef deps do\n  [\n    {:phoenix_seo, \"~> 0.1.11\"}\n  ]\nend\n```","ref":"SEO.html#module-installation"},{"type":"module","title":"Usage - SEO","doc":"1. Define an SEO module for your web application and defaults\n\n```elixir\ndefmodule MyAppWeb.SEO do\n  use MyAppWeb, :verified_routes\n\n  use SEO, [\n    json_library: Jason,\n    # a function reference will be called with a conn during render\n    # arity 1 will be passed the conn, arity 0 is also supported.\n    site: &__MODULE__.site_config/1,\n    open_graph: SEO.OpenGraph.build(\n      description: \"A blog about development\",\n      site_name: \"My Blog\",\n      locale: \"en_US\"\n    ),\n    facebook: SEO.Facebook.build(app_id: \"123\"),\n    twitter: SEO.Twitter.build(\n      site: \"@example\",\n      site_id: \"27704724\",\n      creator: \"@example\",\n      creator_id: \"27704724\",\n      card: :summary\n    )\n  ]\n\n  # Or arity 0 is also supported, which can be great if you're using\n  # Phoenix verified routes and don't need the conn to generate paths.\n  def site_config(conn) do\n    SEO.Site.build(\n      default_title: \"Default Title\",\n      description: \"A blog about development\",\n      title_suffix: \" · My App\",\n      theme_color: \"#663399\",\n      windows_tile_color: \"#663399\",\n      mask_icon_color: \"#663399\",\n      mask_icon_url: static_url(conn, \"/images/safari-pinned-tab.svg\"),\n      manifest_url: url(conn, ~p\"/site.webmanifest\")\n    )\n  end\nend\n```\n\n2. Implement functions to build SEO information about your entities\n\n```elixir\ndefmodule MyApp.Article do\n  # This might be an Ecto schema or a plain struct\n  defstruct [:id, :title, :description, :author, :reading, :published_at]\nend\n\ndefimpl SEO.OpenGraph.Build, for: MyApp.Article do\n  use MyAppWeb, :verified_routes\n\n  def build(article, conn) do\n    SEO.OpenGraph.build(\n      detail:\n        SEO.OpenGraph.Article.build(\n          published_time: article.published_at,\n          author: article.author,\n          section: \"Tech\"\n        ),\n      image: image(article, conn),\n      title: article.title,\n      description: article.description\n    )\n  end\n\n  defp image(article, conn) do\n    file = \"/images/article/#{article.id}.png\"\n\n    exists? =\n      [:code.priv_dir(:my_app), \"static\", file]\n      |> Path.join()\n      |> File.exists?()\n\n    if exists? do\n      SEO.OpenGraph.Image.build(\n        url: static_url(conn, file),\n        alt: article.title\n      )\n    end\n  end\nend\n\ndefimpl SEO.Site.Build, for: MyApp.Article do\n  use MyAppWeb, :verified_routes\n\n  def build(article, conn) do\n    # Because of `Phoenix.Param`, structs will assume the key of `:id` when\n    # interpolating the struct into the verified route.\n    SEO.Site.build(\n      url: url(conn, ~p\"/articles/#{article}\"),\n      title: article.title,\n      description: article.description\n    )\n  end\nend\n\ndefimpl SEO.Twitter.Build, for: MyApp.Article do\n  def build(article, _conn) do\n    SEO.Twitter.build(description: article.description, title: article.title)\n  end\nend\n\ndefimpl SEO.Unfurl.Build, for: MyApp.Article do\n  def build(article, _conn) do\n    SEO.Unfurl.build(\n      label1: \"Reading Time\",\n      data1: \"5 minutes\",\n      label2: \"Published\",\n      data2: DateTime.to_iso8601(article.published_at)\n    )\n  end\nend\n\ndefimpl SEO.Breadcrumb.Build, for: MyApp.Article do\n  use MyAppWeb, :verified_routes\n\n  def build(article, conn) do\n    # Because of `Phoenix.Param`, structs will assume the key of `:id` when\n    # interpolating the struct into the verified route.\n    SEO.Breadcrumb.List.build([\n      %{name: \"Articles\", item: url(conn, ~p\"/articles\")},\n      %{name: article.title, item: url(conn, ~p\"/articles/#{article}\")}\n    ])\n  end\nend\n```\n\n3. Assign the item to your conns and/or sockets\n\n```elixir\n# In a plain Phoenix Controller\ndef show(conn, params) do\n  article = load_article(params)\n\n  conn\n  |> SEO.assign(article)\n  |> render(\"show.html\")\nend\n\ndef index(conn, params) do\n  # Note: it's better to implement a struct that represent a route like this,\n  # so you can customize it per implementation. In this example below, the\n  # `:title` attribute will be passed to all domains.\n  conn\n  |> SEO.assign(%{title: \"Listing Best Hugs\"})\n  |> render(\"show.html\")\nend\n\n# In a Phoenix LiveView, make sure you handle with\n# mount/3 or handle_params/3 so it's present on\n# first static render.\ndef mount(_params, _session, socket) do\n  # You may mark it as temporary since it's only needed on the first render.\n  {:ok, socket, temporary_assigns: [{SEO.key(), nil}]}\nend\n\ndef handle_params(params, _uri, socket) do\n  {:noreply, SEO.assign(socket, load_article(params))}\nend\n```\n\n4. Juice up your root layout:\n\n```heex\n \n  <%# remove the Phoenix-generated <.live_title> component %>\n  <%# and replace with SEO.juice component %>\n   \n \n```\n\nAlternatively, you may selectively render components. For example:\n\n```heex\n \n  <%# With your SEO module's configuration %>\n   \n\n  <%# Or with some other default configuration %>\n   \n\n  <%# Or without defaults %>\n   \n \n```","ref":"SEO.html#module-usage"},{"type":"module","title":"FAQ - SEO","doc":"> #### Question: What do I do for non-show routes, like for index routes? {: .info}\n>\n> You can pass maps or keyword lists for non-specific routes like index routes;\n> however, since it's not an implementation of a struct, it's generic and will be\n> passed to all SEO domains. In the case where an attribute is shared between\n> domains, such as a Twitter title and an Site title and an OpenGraph title, then\n> you won't be able to implement them differently. This is probably ok in most\n> cases.\n>\n> Even better, you can define a struct on your controller or LiveView and pass\n> that struct as the SEO item, then implement the struct per domain.\n>\n> For example:\n>\n> ```elixir\n> defmodule MyAppWeb.PokemonController do\n>   use MyAppWeb, :controller\n>\n>   defstruct [title: \"Listing Pokemon\"]\n>\n>   def index(conn, _params) do\n>     # ... your usual index logic\n>     SEO.assign(conn, %__MODULE__{})\n>   end\n>\n> end\n>\n> defimpl SEO.OpenGraph.Build, for: MyAppWeb.PokemonController do\n>   def build(index, conn) do\n>     SEO.OpenGraph.build(title: index.title, ...)\n>   end\n> end\n> ```\n\n> #### Question: Can I globally configure a JSON library? {: .info}\n>\n> Sure. Without configuration, SEO will choose the JSON library configured\n> for Phoenix. If that's not configured and Jason is available, SEO will use Jason.\n> If Jason is not available, but Poison is, then Poison will be used. In any case,\n> you can specify the JSON library for SEO in your mix config:\n>\n> ```elixir\n> import Config\n> config :phoenix_seo, json_library: Jason\n> ```\n>\n> This will be picked up when you `use SEO` so the config will have json_library\n> available for the components to use later.\n\n> #### Question: What's the difference between `SEO.OpenGraph.Build.build` and `SEO.OpenGraph.build`? {: .info}\n>\n> Elixir protocols are core to how this library works. Using OpenGraph as\n> an example, protocols are defined in SEO domains such as `SEO.OpenGraph.Build`\n> (big B) which are dispatched by Elixir to your implementation for the given struct. This\n> is how polymorphism can work for Elixir! Whereas the function `SEO.OpenGraph.build`\n> (little b) is building the `SEO.OpenGraph` struct based on the defaults for your\n> domain and the result of your implementation. Again, shorter, `Build` (big b) is\n> the protocol, and `build` (little b) is merging your implementation's result with\n> defaults. Technically, your implementation doesn't have to return an\n> `SEO.OpenGraph` struct, but it's very handy since documentation is present on the\n> build function so your editor can quickly show you what is available. Knowing is\n> half the battle!","ref":"SEO.html#module-faq"},{"type":"macro","title":"SEO.__using__/1","doc":"Setup your defaults. Domains are mapped:\n\n- `:site` -> `SEO.Site`\n- `:open_graph` -> `SEO.OpenGraph`\n- `:unfurl` -> `SEO.Unfurl`\n- `:facebook` -> `SEO.Facebook`\n- `:twitter` -> `SEO.Twitter`\n- `:breadcrumb` -> `SEO.Breadcrumb`\n\nFor example:\n\n```elixir\nuse SEO, [\n  site: SEO.Site.build(description: \"My Blog of many words and infrequent posts\", default_title: \"Fanastic Site\")\n  facebook: SEO.Facebook.build(app_id: \"123\")\n]\n```","ref":"SEO.html#__using__/1"},{"type":"function","title":"SEO.assign/2","doc":"Assign the SEO item from the Plug.Conn or LiveView Socket","ref":"SEO.html#assign/2"},{"type":"function","title":"SEO.item/1","doc":"Fetch the SEO item from the Plug.Conn or LiveView Socket","ref":"SEO.html#item/1"},{"type":"function","title":"SEO.juice/1","doc":"Provide SEO juice. Requires an item and passes the item through all available domains\n\n```heex\n \n  <%# remove the Phoenix-generated <.live_title> component %>\n  <%# and replace with SEO.juice component %>\n   \n \n```\n\nAlternatively, you may selectively render components:\n\n```heex\n \n  <%# With your SEO module's configuration %>\n   \n\n  <%# Or with runtime configuration %>\n   \n\n  <%# Or without configuration is fine too %>\n   \n \n```","ref":"SEO.html#juice/1"},{"type":"function","title":"Attributes - SEO.juice/1","doc":"* `conn` (`Plug.Conn`) (required) - `Plug.Conn` for the request. Used for domain configs that are functions and to fetch the item.\n* `item` (`:any`) - Item to render that implements SEO protocols. `SEO.item(@conn)` will be used if not supplied.\n* `page_title` (`:string`) - Page Title. Overrides item's title if supplied. Defaults to `nil`.\n* `config` (`:any`) - Configuration for your SEO module or another module that implements `SEO.Config`. Defaults to `nil`.\n* `json_library` (`:atom`) - JSON library to use when rendering JSON. `config[:json_library]` will be used if not supplied. Defaults to `nil`.","ref":"SEO.html#juice/1-attributes"},{"type":"function","title":"SEO.key/0","doc":"The key used in the conn or socket to find the item","ref":"SEO.html#key/0"},{"type":"type","title":"SEO.attrs/0","doc":"Attributes describing an item","ref":"SEO.html#t:attrs/0"},{"type":"type","title":"SEO.config/0","doc":"Fallback attributes describing an item and configuration","ref":"SEO.html#t:config/0"},{"type":"behaviour","title":"SEO.Config","doc":"Configuration for SEO. This is implemented for you when you `use SEO`","ref":"SEO.Config.html"},{"type":"callback","title":"SEO.Config.config/0","doc":"","ref":"SEO.Config.html#c:config/0"},{"type":"callback","title":"SEO.Config.config/1","doc":"","ref":"SEO.Config.html#c:config/1"},{"type":"function","title":"SEO.Config.domains/0","doc":"","ref":"SEO.Config.html#domains/0"},{"type":"module","title":"SEO.Breadcrumb","doc":"This is SEO for Google to display breadcrumbs in the search results.\nThis allows the search result to search as multiple links.\n\n![Breadcrumb Example](./assets/breadcrumb-example.png)","ref":"SEO.Breadcrumb.html"},{"type":"module","title":"Resources - SEO.Breadcrumb","doc":"- https://developers.google.com/search/docs/data-types/breadcrumbs\n- https://json-ld.org/\n- https://search.google.com/test/rich-results\n- https://search.google.com/structured-data/testing-tool\n\nRendered example inside a ` `:\n\n```json\n{\n  \"@context\": \"https://schema.org\",\n  \"@type\": \"BreadcrumbList\",\n  \"itemListElement\": [{\n    \"@type\": \"ListItem\",\n    \"item\": \"https://bernheisel.com/blog\",\n    \"name\": \"Posts\",\n    \"position\": 1\n  },{\n    \"@type\": \"ListItem\",\n    \"item\": \"https://bernheisel.com/blog/nostalgia-programming\",\n    \"name\": \"Nostalgia, Fun, and Programming\",\n    \"position\": 2\n  }]\n}\n```","ref":"SEO.Breadcrumb.html#module-resources"},{"type":"function","title":"SEO.Breadcrumb.meta/1","doc":"","ref":"SEO.Breadcrumb.html#meta/1"},{"type":"function","title":"Attributes - SEO.Breadcrumb.meta/1","doc":"* `item` (`SEO.Breadcrumb.List`)\n* `json_library` (`:atom`) (required)\n* `config` (`:any`) - Defaults to `nil`.","ref":"SEO.Breadcrumb.html#meta/1-attributes"},{"type":"module","title":"SEO.Facebook","doc":"Facebook originally developed the OpenGraph standard, so much of social-sharing techniques\nare contained in `SEO.OpenGraph`, however there remains one Facebook-specific attribute: the `:app_id`.\n\nResources:\n- https://developers.facebook.com/docs/sharing/webmasters/","ref":"SEO.Facebook.html"},{"type":"function","title":"SEO.Facebook.build/2","doc":"In order to use Facebook Insights you must add the `:app_id` to your page. Insights lets you view analytics for traffic\nto your site from Facebook. Find the app ID in your [Facebook App Dashboard](https://developers.facebook.com/apps/redirect/dashboard).","ref":"SEO.Facebook.html#build/2"},{"type":"function","title":"SEO.Facebook.meta/1","doc":"","ref":"SEO.Facebook.html#meta/1"},{"type":"function","title":"Attributes - SEO.Facebook.meta/1","doc":"* `item` (`SEO.Facebook`) - Defaults to `nil`.\n* `config` (`:any`) - Defaults to `nil`.","ref":"SEO.Facebook.html#meta/1-attributes"},{"type":"type","title":"SEO.Facebook.t/0","doc":"","ref":"SEO.Facebook.html#t:t/0"},{"type":"module","title":"SEO.OpenGraph","doc":"Build OpenGraph tags. This is consumed by platforms such as Google, Facebook, Twitter,\nSlack, and others.\n\nFor example, the following is the OpenGraph markup for the movie \"The Rock\" on IMDB:\n\n```html\n \n \n The Rock (1996) \n \n \n \n \n...\n \n...\n \n```","ref":"SEO.OpenGraph.html"},{"type":"module","title":"Resources - SEO.OpenGraph","doc":"- https://developers.google.com/search/docs/appearance/structured-data/intro-structured-data\n- https://developers.facebook.com/docs/sharing/webmasters/\n- https://developer.twitter.com/en/docs/tweets/optimize-with-cards/overview/markup\n- https://developer.twitter.com/en/docs/tweets/optimize-with-cards/overview/abouts-cards","ref":"SEO.OpenGraph.html#module-resources"},{"type":"function","title":"SEO.OpenGraph.build/2","doc":"Represent your items on the graph of the internet. 🤩🌐📄","ref":"SEO.OpenGraph.html#build/2"},{"type":"function","title":"Basic Metadata - SEO.OpenGraph.build/2","doc":"The four required properties for every page are:\n\n- `:title` - The title of your item as it should appear within the graph, e.g., \"The Rock\".\n- `:detail` - The detail of your item, e.g., `%SEO.OpenGraph.Article{}`.\n- `:image` - An image URL or `SEO.OpenGraph.Image` that represents your item within the graph.\n- `:url` - The canonical URL of your item that will be used as its permanent ID in the graph, e.g.,\n  https://www.imdb.com/title/tt0117500/. Ultimately, this is where the programs will scrape for metadata.\n  For example, if you use a url of a YouTube video page, the scraper will use the OpenGraph tags found on\n  that video page and not the currently-visited site.","ref":"SEO.OpenGraph.html#build/2-basic-metadata"},{"type":"function","title":"Optional Metadata - SEO.OpenGraph.build/2","doc":"The following properties are optional for any item and are generally recommended:\n\n- `:audio` - A URL to a complementing audio file. You may also be more detail with `SEO.OpenGraph.Audio`\n- `:description` - A one to two sentence description of your item.\n- `:determiner` - The word that appears before this item's title in a sentence. An enum of `:a`, `:an`, `:the`,\n  `nil`, `:auto`. If `:auto` is chosen, the consumer of your data should chose between `:a` or `:an`.\n- `:locale` - The locale these tags are marked up in. Of the format language_TERRITORY.\n  Unsupplied is consumed as `\"en_US\"`.\n- `:locale_alternate` - A list of other locales this page is available in and their URLs.\n- `:site_name` - If your item is part of a larger web site, the name which should be displayed for the overall\n  site. e.g., \"IMDb\".\n- `:video` - A URL to a complementing video file. You may also provide more detail with `SEO.OpenGraph.Video`","ref":"SEO.OpenGraph.html#build/2-optional-metadata"},{"type":"function","title":"SEO.OpenGraph.meta/1","doc":"","ref":"SEO.OpenGraph.html#meta/1"},{"type":"function","title":"Attributes - SEO.OpenGraph.meta/1","doc":"* `item` (`SEO.OpenGraph`) - Defaults to `nil`.\n* `config` (`:any`) - Defaults to `nil`.","ref":"SEO.OpenGraph.html#meta/1-attributes"},{"type":"type","title":"SEO.OpenGraph.language_territory/0","doc":"language code and territory code, eg: en_US","ref":"SEO.OpenGraph.html#t:language_territory/0"},{"type":"type","title":"SEO.OpenGraph.open_graph_determiner/0","doc":"The word that appears before this item's title in a sentence.\n\nIf `:auto` is chosen, the consumer of your data should chose between \"a\" or \"an\".","ref":"SEO.OpenGraph.html#t:open_graph_determiner/0"},{"type":"type","title":"SEO.OpenGraph.t/0","doc":"","ref":"SEO.OpenGraph.html#t:t/0"},{"type":"module","title":"SEO.Site","doc":"Metadata about your site.","ref":"SEO.Site.html"},{"type":"module","title":"Example: - SEO.Site","doc":"Mask Icon:\n\n![Mask Icon Example](./assets/masked-icon-example.jpg)\n\nTheme Color:\n\n![Theme Color Example](./assets/theme-color-example.png)","ref":"SEO.Site.html#module-example"},{"type":"module","title":"Resources - SEO.Site","doc":"- https://developer.mozilla.org/en-US/docs/Learn/HTML/Introduction_to_HTML/The_head_metadata_in_HTML\n- https://www.bing.com/webmasters/help/which-robots-metatags-does-bing-support-5198d240\n- https://developers.google.com/search/docs/crawling-indexing/consolidate-duplicate-urls\n- https://developers.google.com/search/docs/crawling-indexing/robots-meta-tag\n- https://developers.google.com/search/docs/crawling-indexing/special-tags\n- https://developers.google.com/search/docs/appearance/snippet (description)\n- https://developers.google.com/search/docs/appearance/site-names (title)\n- https://developers.google.com/search/docs/appearance/title-link\n- https://realfavicongenerator.net/\n- https://developer.apple.com/library/archive/documentation/AppleApplications/Reference/SafariWebContent/pinnedTabs/pinnedTabs.html\n- https://www.w3.org/TR/appmanifest/#using-a-link-element-to-link-to-a-manifest","ref":"SEO.Site.html#module-resources"},{"type":"function","title":"SEO.Site.build/2","doc":"Metadata that describes the site generally.\n\n- `:title` - Title of the page. If `:page_title` is provided to the component, that will always win.\n- `:default_title` - Fallback title when `:title` and `:page_title` is nil.\n- `:description` - A one to two sentence description of your item.\n- `:canonical_url` - A URL that is most representative of your item.\n- `:rating` - `\"adult\"`. If a rating of `\"adult\"` is applied, it's also recommended to separate adult assets into a\nfolder such as `example.com/explicit/wow.jpg`. No value provided means the content is appropriate for everyone.\n- `:alternate_languages` -  If your site is multilingual, you can inform search engines. Supply a list of tuples of the\nlang_code and the URL for the page. For example:\n      [\n        {\"en_US\", Routes.article_url(@endpoint, article.id)},\n        {\"ja_JP\", Routes.article_jp_url(@endpoint, article.id)}\n      ]\n- `:google` - Google-specific metadata. It can be one of these values or a list of these values:\n  - `\"nositelinkssearch\"`. When users search for your site, Google Search results sometimes display a search box\n  specific to your site, along with other direct links to your site. This tag tells Google not to show the sitelinks\n  search box. [Learn more about sitelinks search box.](https://developers.google.com/search/docs/appearance/structured-data/sitelinks-searchbox)\n  - `\"nopagereadaloud\"` - Prevents various [Google text-to-speech services](https://developers.google.com/search/docs/crawling-indexing/read-aloud-user-agent) from reading aloud web pages using text-to-speech (TTS). Prevents various\n- `:googlebot` - Google crawler bot metadata.\n  - `\"notranslate\"` - when Google recognizes that the contents of a page aren't in the language that the user\n  likely wants to read, Google may provide a translated title link and snippet in search results. If the user\n  clicks the translated title link, all further user interaction with the page is through Google Translate,\n  which will automatically translate any links followed. In general, this gives you the chance to provide\n  your unique and compelling content to a much larger group of users. However, there may be situations where\n  this is not desired. This meta tag tells Google that you don't want Google to provide a translation for\n  this page.\n- `:google_site_verification` - You can use this tag on the top-level page of your site to verify ownership for Search\nConsole. Please note that while the values of the name and content attributes must match exactly what is provided to\nyou (including upper and lower case), it doesn't matter if you change the tag from XHTML to HTML or if the format of\nthe tag matches the format of your page.\n- `:robots` - Robot instructions. You may provide or a list of the values:\n  - `\"noindex\"` do not index the page\n  - `\"noimageindex\"` do not index images on this page. If you don't specify this value, images on the page may be\n  indexed and shown in search results.\n  - `unavailable_after: [date/time]` do not show this page in search results after the specified date/time. The\n  date/time must be specified in a widely adopted format including ISO 8601.\n  - `\"nofollow\"` do not follow outlines from the page.\n  - `\"none\"` Equivalent to `noindex, nofollow`\n  - `\"all\"` There are no restrictions for indexing or serving. This directive is the default value and has no effect if explicitly listed.\n  - `\"indexifembedded\"` Google is allowed to index the content of a page if it's embedded in another page through\n  iframes or similar HTML tags, in spite of a noindex directive.\n  - `\"notranslate\"` don't offer translation of this page in search results\n  - `\"noarchive\"` do not store a cached page\n  - `\"nocache\"` do not store a cached page. Same as `\"noarchive\"`\n  - `\"noodp\"` do not use a description from [Open Directory Project](http://dmoz.org)\n  - `\"nosnippet\"` do not show a description nor a preview thumbnail for the page\n  - `\"max-snippet:[number]\"` max text length in characters to show in search results. The number may be:\n    - `0` no text snippet\n    - `-1` no limit\n  - `\"max-image-preview:[value]\"` Max size of an image preview. The value may be:\n    - `none` do not show an image preview\n    - `standard` show a standard size image\n    - `large` show a large size image\n    - any other value will mean there is no image size limit\n  - `\"max-video-preview:[number]\"` Max number of seconds of a video preview. The number may be:\n    - `0` show a static image instead\n    - `-1` allow any preview length\n- `:windows_tile_color` - The color of the tile behind your icon when rendered on the Microsoft Windows start menu.\n  Accepts a CSS color value, such as a hex or name.\n- `:theme_color` - The chrome of the browser may use the theme color. Accepts a CSS color value. It creates a nice\n  effect if this is set to the same color as the page's background. In Safari, this is used when the tab bar style is\n  compact. Some colors may be ignored by the browser (such as those that conflict with the chrome).\n- `:mask_icon_url` - URL of the mask SVG icon. Accepts an `%URI{}` or a string. This is used by Safari when the page\n  is pinned to a tab. The SVG file must use 100% black for all vectors with a transparent background, a single layer,\n  and the viewBox attribute must be set to `\"0 0 16 16\"`.\n- `:mask_icon_color` - Safari will use the `:mask_icon_url` as the icon when pinned, and you may colorize the icon\n  with a CSS color value.","ref":"SEO.Site.html#build/2"},{"type":"function","title":"SEO.Site.meta/1","doc":"","ref":"SEO.Site.html#meta/1"},{"type":"function","title":"Attributes - SEO.Site.meta/1","doc":"* `item` (`:any`) - Defaults to `nil`.\n* `page_title` (`:string`) - Defaults to `nil`.\n* `config` (`:any`) - Defaults to `nil`.","ref":"SEO.Site.html#meta/1-attributes"},{"type":"type","title":"SEO.Site.css_color/0","doc":"CSS color value.  For example, \"#663399\", \"red\", \"rgb(0, 1, 3)\". https://www.w3.org/TR/css-color-3/","ref":"SEO.Site.html#t:css_color/0"},{"type":"type","title":"SEO.Site.t/0","doc":"","ref":"SEO.Site.html#t:t/0"},{"type":"module","title":"SEO.Twitter","doc":"With Twitter Cards, you can attach rich photos, videos and media experiences to Tweets, helping to drive traffic to\nyour website. Users who Tweet links to your content will have a \"Card\" added to the Tweet that's visible to their\nfollowers.\n\nExamples\n\nSummary card with large image: ![Summary card with Large Image](./assets/twitter-summary-large-example.png)\n\nPlayer card: ![Player card](./assets/twitter-player-example.png)","ref":"SEO.Twitter.html"},{"type":"module","title":"Resources - SEO.Twitter","doc":"- https://developer.twitter.com/en/docs/twitter-for-websites/cards/guides/getting-started","ref":"SEO.Twitter.html#module-resources"},{"type":"function","title":"SEO.Twitter.build/2","doc":"Build tags that customize how Twitter displays your page.\n\n- `:card` - The different `:card` types each have a different presentation\n  - `:summary` - card with title, description, and thumbnail.\n  - `:summary_large_image` - similar to the `:summary` card, but with a prominently-featured image.\n  - `:app` - card with a direct download to a mobile app.\n  - `:player` - card that can display video/audio/media.\n- `:creator` - The Twitter @username the card should be attributed to.\n- `:creator_id` - The Twitter id of the user the card should be attributed to.\n- `:site` - The Twitter @username for the website.\n- `:site_id` - The Twitter id for the website.\n- `:title` - A concise title for the related content.\n- `:description` - A description that concisely summarizes the content as appropriate for presentation within a Tweet.\n- `:image` - A URL to a unique image representing the content of the page. You should not use a generic\nimage such as your website logo, author photo, or other image that spans multiple pages. Images for this\nCard support an aspect ratio of 2:1 with minimum dimensions of 300x157 or maximum of 4096x4096 pixels.\nImages must be less than 5MB in size. JPG, PNG, WEBP and GIF formats are supported. Only the first frame\nof an animated GIF will be used. SVG is not supported.\n- `:image_alt` - A text description of the image conveying the essential nature of an image to users who\nare visually impaired. Maximum 420 characters.\n- `:player` - HTTPS URL of player iframe\n- `:player_width` - Width of iframe in pixels\n- `:player_height` - Height of iframe in pixels\n- `:player_stream` - URL to raw video or audio stream\n- `:app_name_iphone` - Name of your iPhone app\n- `:app_id_iphone` - Your app ID in the iTunes App Store\n- `:app_url_iphone` - Your app's custom URL scheme\n- `:app_name_ipad` - Name of your iPad optimized app\n- `:app_id_ipad` - Your app ID in the iTunes App Store\n- `:app_url_ipad` - Your app's custom URL scheme\n- `:app_name_googleplay` - Name of your Android app\n- `:app_id_googleplay` - Your app ID in the Google Play Store\n- `:app_url_googleplay` - Your app’s custom URL scheme\n- `:app_country` - If your application is not available in the US App Store, you must set this value to the two-letter country code for the App Store that contains your application.\n\nIf used alongside the OpenGraph tags, the Twitter tags will win when shared on Twitter. If not provided, Twitter will\nuse the OpenGraph tags. Unless you have specific messaging for Twitter followers, it's typically good enough to use\nOpenGraph for most data.","ref":"SEO.Twitter.html#build/2"},{"type":"function","title":"SEO.Twitter.meta/1","doc":"","ref":"SEO.Twitter.html#meta/1"},{"type":"function","title":"Attributes - SEO.Twitter.meta/1","doc":"* `item` (`SEO.Twitter`) - Defaults to `nil`.\n* `config` (`:any`) - Defaults to `nil`.","ref":"SEO.Twitter.html#meta/1-attributes"},{"type":"type","title":"SEO.Twitter.creator/0","doc":"@username for the content creator / author","ref":"SEO.Twitter.html#t:creator/0"},{"type":"type","title":"SEO.Twitter.pixels/0","doc":"","ref":"SEO.Twitter.html#t:pixels/0"},{"type":"type","title":"SEO.Twitter.site/0","doc":"@username for the website used in the card footer","ref":"SEO.Twitter.html#t:site/0"},{"type":"type","title":"SEO.Twitter.t/0","doc":"","ref":"SEO.Twitter.html#t:t/0"},{"type":"module","title":"SEO.Unfurl","doc":"Some platforms (eg, Slack and Discord) have adopted an older and deprecated Twitter Product Card specification that\nallows for two arbitrary data points. For example, some blogs may include a reading time. Another example, if selling a product you may display a variation (eg, color is black) and also display the price (eg, price is $20).\n\nThis module should be used alongside the `SEO.OpenGraph` module for completeness.\n\nFor example, in the screenshot below, `:label1` is `\"Reading Time\"` and `:data1` is `\"15 minutes\"`, and `:label2` is\n`\"Published\"` and `:data2` is `\"2020-01-19\"`.\n\n![Unfurl example](./assets/unfurl-example.png)\n\nResources\n- https://api.slack.com/reference/messaging/link-unfurling#classic_unfurl","ref":"SEO.Unfurl.html"},{"type":"function","title":"SEO.Unfurl.build/2","doc":"Arbitrary data points about your object. label1 and data1 both should be provided in order to render. Same with label2/data2.\n\nFor example, label1 could be `\"price\"` and data1 could be `\"$10\"`.\n\n- `:label1` - Label describing data1\n- `:data1` - 1st data point\n- `:label2` - Label describing data2\n- `:data2` - 2nd data point","ref":"SEO.Unfurl.html#build/2"},{"type":"function","title":"SEO.Unfurl.meta/1","doc":"","ref":"SEO.Unfurl.html#meta/1"},{"type":"function","title":"Attributes - SEO.Unfurl.meta/1","doc":"* `item` (`SEO.Unfurl`) - Defaults to `nil`.\n* `config` (`:any`) - Defaults to `nil`.","ref":"SEO.Unfurl.html#meta/1-attributes"},{"type":"type","title":"SEO.Unfurl.t/0","doc":"","ref":"SEO.Unfurl.html#t:t/0"},{"type":"module","title":"SEO.OpenGraph.Article","doc":"Metadata describing an article.","ref":"SEO.OpenGraph.Article.html"},{"type":"module","title":"Resources - SEO.OpenGraph.Article","doc":"- https://ogp.me/#type_article","ref":"SEO.OpenGraph.Article.html#module-resources"},{"type":"function","title":"SEO.OpenGraph.Article.build/2","doc":"Build metadata about an article.\n\n- `:published_time` - when the article was first published.\n- `:modified_time` - when the article was last changed.\n- `:expiration_time` - when the article is out of date after.\n- `:author` - Writers of the article. This can be nested author OpenGraph metadata or URLs that\nprovide the metadata or simply the author's name.\n- `:section` - A high-level section name. E.g. `\"Technology\"`\n- `:tag` - Tag words associated with this article. E.g. `[\"Elixir\", \"Ecto\"]`","ref":"SEO.OpenGraph.Article.html#build/2"},{"type":"function","title":"SEO.OpenGraph.Article.meta/1","doc":"","ref":"SEO.OpenGraph.Article.html#meta/1"},{"type":"function","title":"Attributes - SEO.OpenGraph.Article.meta/1","doc":"* `content` (`SEO.OpenGraph.Article`) - Defaults to `nil`.","ref":"SEO.OpenGraph.Article.html#meta/1-attributes"},{"type":"type","title":"SEO.OpenGraph.Article.t/0","doc":"","ref":"SEO.OpenGraph.Article.html#t:t/0"},{"type":"module","title":"SEO.OpenGraph.Audio","doc":"Data describing an audio file.","ref":"SEO.OpenGraph.Audio.html"},{"type":"function","title":"SEO.OpenGraph.Audio.build/2","doc":"The `og:audio` property has some optional structured properties:\n\n- `:url` - The url with metadata that describes the audio.\n- `:secure_url` - An alternate url to use if the webpage requires HTTPS.\n- `:type` - A MIME type for this audio, eg, `\"audio/mpeg\"`.","ref":"SEO.OpenGraph.Audio.html#build/2"},{"type":"function","title":"SEO.OpenGraph.Audio.meta/1","doc":"","ref":"SEO.OpenGraph.Audio.html#meta/1"},{"type":"function","title":"Attributes - SEO.OpenGraph.Audio.meta/1","doc":"* `content` (`:any`) - Defaults to `nil`.","ref":"SEO.OpenGraph.Audio.html#meta/1-attributes"},{"type":"type","title":"SEO.OpenGraph.Audio.mime/0","doc":"","ref":"SEO.OpenGraph.Audio.html#t:mime/0"},{"type":"type","title":"SEO.OpenGraph.Audio.t/0","doc":"","ref":"SEO.OpenGraph.Audio.html#t:t/0"},{"type":"module","title":"SEO.OpenGraph.Book","doc":"Metadata describing a book","ref":"SEO.OpenGraph.Book.html"},{"type":"module","title":"Resources - SEO.OpenGraph.Book","doc":"- https://ogp.me/#type_book","ref":"SEO.OpenGraph.Book.html#module-resources"},{"type":"function","title":"SEO.OpenGraph.Book.build/2","doc":"Metadata that describes a book.\n\n- `:author` - Who wrote this book. This may be a name or a URL that implements `SEO.OpenGraph.Profile` for the author\n  with additional details. This may be supplied as a list of authors.\n- `:isbn` - The ISBN\n- `:release_date` - The date the book was released.\n- `:tag` - Tag words associated with this book.","ref":"SEO.OpenGraph.Book.html#build/2"},{"type":"function","title":"SEO.OpenGraph.Book.meta/1","doc":"","ref":"SEO.OpenGraph.Book.html#meta/1"},{"type":"function","title":"Attributes - SEO.OpenGraph.Book.meta/1","doc":"* `content` (`SEO.OpenGraph.Book`) - Defaults to `nil`.","ref":"SEO.OpenGraph.Book.html#meta/1-attributes"},{"type":"type","title":"SEO.OpenGraph.Book.t/0","doc":"","ref":"SEO.OpenGraph.Book.html#t:t/0"},{"type":"module","title":"SEO.OpenGraph.Image","doc":"URL or details for the image. The `og:image` property has some optional structured properties:\n\n**NOTE**: to update an image after it's been published, use a new URL for the new image. Images are typically cached\nbased on the URL and won't be updated unless the URL changes. In Phoenix, the URL is typically using a hashed\nversion of the image (see `mix phx.digest`), so this should be handled automatically.\n\nBest practices:\n- Use images that are at least 1080 pixels in width for best display on high resolution devices. At the minimum, you should use images that are 600 pixels in width to display image link ads. We recommend using 1:1 images in your ad creatives for better performance with image link ads.\n- Pre-cache your images by running the URL through the URL Sharing Debugger tool to pre-fetch metadata for the website. You should also do this if you update the image for a piece of content.\n- Use `:width` and `:height` to specify the image dimensions to the crawler so that it can render the image immediately without having to asynchronously download and process it.\n\nResources\n- https://ogp.me/#structured\n- https://developers.facebook.com/docs/sharing/best-practices#images","ref":"SEO.OpenGraph.Image.html"},{"type":"function","title":"SEO.OpenGraph.Image.build/2","doc":"Build an OpenGraph image\n\n- `:url` - Identical to `og:image`.\n- `:secure_url` - An alternate url to use if the webpage requires HTTPS. If not supplied but `:url` starts with\n  \"https\" then this will be populated with the url as well.\n- `:type` - A MIME type for this image.\n- `:width` - The number of pixels wide.\n- `:height` - The number of pixels high.\n- `:alt` - A description of what is in the image (not a caption). If the page specifies an image it should\nalso specify `:alt`.","ref":"SEO.OpenGraph.Image.html#build/2"},{"type":"function","title":"SEO.OpenGraph.Image.meta/1","doc":"","ref":"SEO.OpenGraph.Image.html#meta/1"},{"type":"function","title":"Attributes - SEO.OpenGraph.Image.meta/1","doc":"* `content` (`:any`) - Either an `SEO.OpenGraph.Image`, a string, or a URI. Defaults to `nil`.","ref":"SEO.OpenGraph.Image.html#meta/1-attributes"},{"type":"type","title":"SEO.OpenGraph.Image.mime/0","doc":"","ref":"SEO.OpenGraph.Image.html#t:mime/0"},{"type":"type","title":"SEO.OpenGraph.Image.pixels/0","doc":"","ref":"SEO.OpenGraph.Image.html#t:pixels/0"},{"type":"type","title":"SEO.OpenGraph.Image.t/0","doc":"","ref":"SEO.OpenGraph.Image.html#t:t/0"},{"type":"module","title":"SEO.OpenGraph.Profile","doc":"","ref":"SEO.OpenGraph.Profile.html"},{"type":"module","title":"Resources - SEO.OpenGraph.Profile","doc":"- https://ogp.me/#type_profile","ref":"SEO.OpenGraph.Profile.html#module-resources"},{"type":"function","title":"SEO.OpenGraph.Profile.build/2","doc":"Build a OpenGraph Profile\n\n- `:first_name` - A name normally given to an individual by a parent or self-chosen.\n- `:last_name` - A name inherited from a family or marriage and by which the individual is commonly known.\n- `:username` - A short unique string to identify them.\n- `:gender` - Their gender.","ref":"SEO.OpenGraph.Profile.html#build/2"},{"type":"function","title":"SEO.OpenGraph.Profile.meta/1","doc":"","ref":"SEO.OpenGraph.Profile.html#meta/1"},{"type":"function","title":"Attributes - SEO.OpenGraph.Profile.meta/1","doc":"* `content` (`:any`) - Defaults to `nil`.\n* `property` (`:string`) - Defaults to `\"profile\"`.","ref":"SEO.OpenGraph.Profile.html#meta/1-attributes"},{"type":"type","title":"SEO.OpenGraph.Profile.t/0","doc":"","ref":"SEO.OpenGraph.Profile.html#t:t/0"},{"type":"module","title":"SEO.OpenGraph.Video","doc":"Data describing a video.\n\nCommonly, an `og:video` is accompanied with an `og:image` that provides the preview image for the video.","ref":"SEO.OpenGraph.Video.html"},{"type":"module","title":"Resources - SEO.OpenGraph.Video","doc":"- https://ogp.me/#structured\n- https://developers.facebook.com/docs/sharing/webmasters/#video\n- https://yandex.com/support/video/partners/open-graph.html","ref":"SEO.OpenGraph.Video.html#module-resources"},{"type":"function","title":"SEO.OpenGraph.Video.build/2","doc":"The `og:video` property has some optional structured properties:\n\n- `:url` - The url with metadata that describes the video.\n- `:secure_url` - An alternate url to use if the webpage requires HTTPS. If the URL starts with `https` then\n- `:type` - A MIME type for this video. Facebook supports both mp4 and Flash videos, `application/x-shockwave-flash`\n  or `video/mp4`, but please for the love of all that is holy don't use Shockwave Flash.\n- `:width` - The width in pixels.\n- `:height` - The height in pixels.\n- `:alt` - A description of what is in the video (not a caption). If the page specifies an `og:video` it should\n  specify `og:video:alt`.\n\nSupply a secure URL for both the `og:video:url` and `og:video:secure_url` tags to make your video eligible to play\nin-line in Facebook's Feed.\n\nFor Yandex, there are additional properties:\n\n- `:ya_bitrate` - Maximum bitrate in kilobits per second\n- `:ya_allow_embed` - Allow embedding in Yandex search results\n- `:ya_quality` - The quality in resolution and bitrate\n  - `:low` - Low quality with resolution less than 360x640 and bitrate lower than 717kbps\n  - `:medium` - Average quality with resolution between 360x640 and 720x1280 and bitrate between than 717kbps-1Mbps\n  - `:hd` - HD quality with resolution between 720x1280 and 1080x1920 and bitrate between than 1MBps-2Mbps\n  - `:full_hd` - 1080p quality with resolution greater than 1080x1920 and bitrate higher than 2Mbps","ref":"SEO.OpenGraph.Video.html#build/2"},{"type":"function","title":"SEO.OpenGraph.Video.meta/1","doc":"","ref":"SEO.OpenGraph.Video.html#meta/1"},{"type":"function","title":"Attributes - SEO.OpenGraph.Video.meta/1","doc":"* `content` (`:any`) - Defaults to `nil`.","ref":"SEO.OpenGraph.Video.html#meta/1-attributes"},{"type":"type","title":"SEO.OpenGraph.Video.mime/0","doc":"","ref":"SEO.OpenGraph.Video.html#t:mime/0"},{"type":"type","title":"SEO.OpenGraph.Video.pixels/0","doc":"","ref":"SEO.OpenGraph.Video.html#t:pixels/0"},{"type":"type","title":"SEO.OpenGraph.Video.t/0","doc":"","ref":"SEO.OpenGraph.Video.html#t:t/0"},{"type":"type","title":"SEO.OpenGraph.Video.yandex_bitrate/0","doc":"","ref":"SEO.OpenGraph.Video.html#t:yandex_bitrate/0"},{"type":"type","title":"SEO.OpenGraph.Video.yandex_quality/0","doc":"","ref":"SEO.OpenGraph.Video.html#t:yandex_quality/0"},{"type":"module","title":"SEO.Breadcrumb.List","doc":"A `SEO.Breadcrumb.List` is list of items consisting of a chain of linked Web pages, typically\ndescribed using at least their URL and their name, and typically ending with the current page.\n\nThe `:position` property is used to reconstruct the order of the items in a `SEO.Breadcrumb.List`.\nThe convention is that a breadcrumb list has an `itemListOrder` of `ItemListOrderAscending`\n(lower values listed first), and that the first items in this list correspond to the \"top\"\nor beginning of the breadcrumb trail, e.g. with a site or section homepage. The specific values\nof 'position' are not assigned meaning for a BreadcrumbList, but they should be integers,\ne.g. beginning with '1' for the first item in the list.","ref":"SEO.Breadcrumb.List.html"},{"type":"function","title":"SEO.Breadcrumb.List.build/2","doc":"Build a list of items that represent breadcrumbs for your item.\n\nYou may build the list with `SEO.Breadcrumb.ListItem` or with attributes that will build\na ListItem. The position will be inferred from the list provided, but if you need to\nsupply the position manually, you must supply `SEO.Breadcrumb.ListItem`.\n\nFor example:\n\n```elixir\nSEO.Breadcrumb.List.build([\n  %{name: \"Posts\", item: Routes.blog_url(@endpoint, :index)},\n  %{name: \"My Post\", item: Routes.blog_url(@endpoint, :show, my_id)}\n])\n```","ref":"SEO.Breadcrumb.List.html#build/2"},{"type":"type","title":"SEO.Breadcrumb.List.t/0","doc":"","ref":"SEO.Breadcrumb.List.html#t:t/0"},{"type":"module","title":"SEO.Breadcrumb.ListItem","doc":"One item in a `SEO.Breadcrumb.List`","ref":"SEO.Breadcrumb.ListItem.html"},{"type":"function","title":"SEO.Breadcrumb.ListItem.build/2","doc":"One item within a breadcrumb list.\n\nThe two required keys for every item are:\n\n- `:item` - The URL of the item, eg: \"https://example.com/cats\".\n- `:name` - The name of the item, eg: \"Cats\"\n\nYou may optionally provide the position. If unset, then one will be generated\nfor you based on its position in the list. (1-based)\n\n- `:position` - The position in the breadcrumb list, eg: 1 (first)\n\nFor example:\n\n```elixir\nSEO.Breadcrumb.ListItem.build(%{\n  name: \"Posts\",\n  item: Routes.blog_url(@endpoint, :index)\n})\n```","ref":"SEO.Breadcrumb.ListItem.html#build/2"},{"type":"type","title":"SEO.Breadcrumb.ListItem.t/0","doc":"","ref":"SEO.Breadcrumb.ListItem.html#t:t/0"},{"type":"protocol","title":"SEO.Breadcrumb.Build","doc":"Implement `build/2` which receives your item and conn and returns a `SEO.Breadcrumb.List.t` or `nil`","ref":"SEO.Breadcrumb.Build.html"},{"type":"function","title":"SEO.Breadcrumb.Build.build/2","doc":"","ref":"SEO.Breadcrumb.Build.html#build/2"},{"type":"type","title":"SEO.Breadcrumb.Build.t/0","doc":"All the types that implement this protocol.","ref":"SEO.Breadcrumb.Build.html#t:t/0"},{"type":"protocol","title":"SEO.Facebook.Build","doc":"Implement `build/2` which receives your item and conn and returns a `SEO.Facebook.t` or `nil`","ref":"SEO.Facebook.Build.html"},{"type":"function","title":"SEO.Facebook.Build.build/2","doc":"","ref":"SEO.Facebook.Build.html#build/2"},{"type":"type","title":"SEO.Facebook.Build.t/0","doc":"All the types that implement this protocol.","ref":"SEO.Facebook.Build.html#t:t/0"},{"type":"protocol","title":"SEO.OpenGraph.Build","doc":"Implement `build/2` which receives your item and conn and returns a `SEO.OpenGraph.t` or `nil`","ref":"SEO.OpenGraph.Build.html"},{"type":"function","title":"SEO.OpenGraph.Build.build/2","doc":"","ref":"SEO.OpenGraph.Build.html#build/2"},{"type":"type","title":"SEO.OpenGraph.Build.t/0","doc":"All the types that implement this protocol.","ref":"SEO.OpenGraph.Build.html#t:t/0"},{"type":"protocol","title":"SEO.Site.Build","doc":"Implement `build/2` which receives your item and conn and returns a `SEO.Site.t` or `nil`","ref":"SEO.Site.Build.html"},{"type":"function","title":"SEO.Site.Build.build/2","doc":"","ref":"SEO.Site.Build.html#build/2"},{"type":"type","title":"SEO.Site.Build.t/0","doc":"All the types that implement this protocol.","ref":"SEO.Site.Build.html#t:t/0"},{"type":"protocol","title":"SEO.Twitter.Build","doc":"Implement `build/2` which receives your item and conn and returns a `SEO.Twitter.t` or `nil`","ref":"SEO.Twitter.Build.html"},{"type":"function","title":"SEO.Twitter.Build.build/2","doc":"","ref":"SEO.Twitter.Build.html#build/2"},{"type":"type","title":"SEO.Twitter.Build.t/0","doc":"All the types that implement this protocol.","ref":"SEO.Twitter.Build.html#t:t/0"},{"type":"protocol","title":"SEO.Unfurl.Build","doc":"Implement `build/2` which receives your item and conn and returns a `SEO.Unfurl.t` or `nil`","ref":"SEO.Unfurl.Build.html"},{"type":"function","title":"SEO.Unfurl.Build.build/2","doc":"","ref":"SEO.Unfurl.Build.html#build/2"},{"type":"type","title":"SEO.Unfurl.Build.t/0","doc":"All the types that implement this protocol.","ref":"SEO.Unfurl.Build.html#t:t/0"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.1.11 (2024-11-25) - Changelog","doc":"- Bugfix: Correct `locale_alternate` handling. Thank you @Hermanverschooten","ref":"changelog.html#0-1-11-2024-11-25"},{"type":"extras","title":"0.1.10 (2024-07-21) - Changelog","doc":"- Relax Phoenix Live View requirement. Thank you @srcrip","ref":"changelog.html#0-1-10-2024-07-21"},{"type":"extras","title":"0.1.9 (2024-02-19) - Changelog","doc":"- Fix twitter card. An empty value would always render `summary`. Thank you @Flo0807.","ref":"changelog.html#0-1-9-2024-02-19"},{"type":"extras","title":"0.1.8 (2023-01-25) - Changelog","doc":"- Fix behavior when no item is provided. Component was defaulting to nil for\n  item when didn't let fallback to work. Thank you @hwatkins.","ref":"changelog.html#0-1-8-2023-01-25"},{"type":"extras","title":"0.1.7 (2022-12-08) - Changelog","doc":"- BREAKING: simplify OpenGraph fields `:type` and `:type_detail` into one\n  `:detail`. The appropriate struct or values in `:detail` will infer to the type.","ref":"changelog.html#0-1-7-2022-12-08"},{"type":"extras","title":"0.1.6 (2022-10-17) - Changelog","doc":"- Add SEO.Config @behaviour and implement it during `use SEO`.\n- SEO config is now a struct instead of a map","ref":"changelog.html#0-1-6-2022-10-17"},{"type":"extras","title":"0.1.5 (2022-10-16) - Changelog","doc":"- Allow for config to be a module that implements `config/0` and `config/1`\n- Allow for domain config to be a function reference that receives a conn\n- BREAKING: rework implementation to be arity 2 that accepts the item and the conn.","ref":"changelog.html#0-1-5-2022-10-16"},{"type":"extras","title":"0.1.4 (2022-10-16) - Changelog","doc":"- Fix empty breadcrumbs\n- Squash newlines and trim description","ref":"changelog.html#0-1-4-2022-10-16"},{"type":"extras","title":"0.1.3 (2022-10-14) - Changelog","doc":"- Fix fetching SEO item from LiveView\n- Improve docs.","ref":"changelog.html#0-1-3-2022-10-14"},{"type":"extras","title":"0.1.2 (2022-10-14) - Changelog","doc":"- Don't limit rendering twitter card meta\n- Improve docs.","ref":"changelog.html#0-1-2-2022-10-14"},{"type":"extras","title":"0.1.1 (2022-10-14) - Changelog","doc":"- Rework implementation.","ref":"changelog.html#0-1-1-2022-10-14"},{"type":"extras","title":"0.1.0 (2022-10-13) - Changelog","doc":"- Initial release","ref":"changelog.html#0-1-0-2022-10-13"},{"type":"extras","title":"LICENSE","doc":"Copyright 2022 David Bernheisel\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of\nthis software and associated documentation files (the \"Software\"), to deal in\nthe Software without restriction, including without limitation the rights to\nuse, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of\nthe Software, and to permit persons to whom the Software is furnished to do so,\nsubject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS\nFOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR\nCOPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER\nIN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN\nCONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}